@@ -4,6 +4,7 @@ import logging
 import os
 import re
 import shutil
+import zipfile
 from datetime import datetime
 from pathlib import Path, PurePosixPath
 from subprocess import Popen, PIPE, STDOUT
@@ -91,9 +92,9 @@ class FollowLog:
                 yield from self.process(part.decode())
 
 
-class Scene:
-    def __init__(self, scene: str):
-        self.path = PurePosixPath(scene)
+class Key:
+    def __init__(self, key: str):
+        self.path = PurePosixPath(key)
 
     @property
     def task_id(self):
@@ -115,11 +116,21 @@ class Scene:
 
 
 class Render:
-    def __init__(self, scene: Scene, client: S3):
+    def __init__(self, scene: Key, client: S3, texture: str = None):
         self.scene = scene
         self.client = client
+        self.texture = texture and Key(texture)
+
+    def unpack_texture(self):
+        if self.texture:
+            self.client.download_file(self.texture.path, self.texture.localfile)
+            logger.info(f"Texture downloaded - {self.texture.localfile}")
+            with zipfile.ZipFile(self.texture.localfile, 'r') as f:
+                f.extractall(self.texture.workdir)
+            logger.info(f"Texture unzipped to - {self.texture.workdir}")
 
     def run(self, extension='exr'):
+        self.unpack_texture()
         self.client.download_file(self.scene.path, self.scene.localfile)
         logger.info(f"Scene downloaded - {self.scene.localfile}")
         if not self.scene.localfile.is_file():
@@ -163,7 +174,7 @@ def record_time(f):
     return wrapper
 
 
-def collect_logs(scene: Scene, client: S3):
+def collect_logs(scene: Key, client: S3):
     logger.info("Collecting log files...")
     for file in itertools.chain(
             # additional logs could be appended here
@@ -177,15 +188,15 @@ def collect_logs(scene: Scene, client: S3):
         )
 
 
-def run(scene_key):
+def run(scene_key, texture=None):
     assert os.environ['ADSK_3DSMAX_x64_2018'], "ADSK_3DSMAX_x64_2018 must be defined"
 
     s3 = AWS_S3()
-    scene = Scene(scene_key)
+    scene = Key(scene_key)
     # configure current logger for the specific scene
     configure_logger(scene.workdir / 'task.log')
 
-    render = Render(scene, client=s3)
+    render = Render(scene, s3, texture)
     try:
         rc = record_time(render.run)()
         if rc > 0:
@@ -197,6 +208,4 @@ def run(scene_key):
         collect_logs(scene, s3)
 
 
-@celery.task(name="run")
-def main(*args, **kwargs):
-    run(*args, **kwargs)
+celery.task(name="run")(run)
