@@ -1,6 +1,7 @@
 import logging
-import os
+from logging import DEBUG
 from logging.config import dictConfig
+from pathlib import Path
 
 logging.getLogger("requests").setLevel(logging.WARNING)
 logging.getLogger("urllib3").setLevel(logging.WARNING)
@@ -13,11 +14,8 @@ logging.getLogger("s3transfer").setLevel(logging.WARNING)
 logging.getLogger("celery").setLevel(logging.ERROR)
 
 
-def configure_logger(log_dir, level="DEBUG"):
-    """Logger configuration"""
-
-    os.makedirs(log_dir, exist_ok=True)
-
+def configure_logger(filename: Path, level=logging.getLevelName(DEBUG)):
+    filename.parent.mkdir(exist_ok=True)
     dictConfig({
         'version': 1,
         'disable_existing_loggers': False,
@@ -36,7 +34,7 @@ def configure_logger(log_dir, level="DEBUG"):
                 'level': level,
                 'formatter': 'standard',
                 'class': 'logging.FileHandler',
-                'filename': log_dir / 'task.log'
+                'filename': filename
             },
         },
         'loggers': {
