@@ -1,9 +1,12 @@
+import logging
 import re
 
 import win32com.client
 import win32con
 import win32gui
 
+logger = logging.getLogger(__name__)
+
 
 class WindowMgr:
     """Encapsulates some calls to the winapi for window management"""
@@ -21,7 +24,10 @@ class WindowMgr:
 
     def find_window_wildcard(self, wildcard):
         self.handle = None
+        logger.debug(f"Trying to find window '{wildcard}'")
         win32gui.EnumWindows(self._window_enum_callback, wildcard)
+        if self.handle:
+            logger.debug(f"The window is found - {self.handle}")
 
     def foreground(self):
         if self.handle is not None:
